==> jc-1.4.0.tar.gz: java/util/zip/CheckedOutputStream.h <==
// public class java.util.zip.CheckedOutputStream

// class file dependencies
// @dep_class fddb41323d9c4cee java_io_FilterOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a389f1f7f4dc0310 java_util_zip_CheckedOutputStream

// header file dependencies
// @dep_header java_io_FilterOutputStream

#include "java/io/FilterOutputStream.h"

#ifndef _JC_java_util_zip_CheckedOutputStream_H_
#define _JC_java_util_zip_CheckedOutputStream_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_zip_Checksum$object;

// Typedefs
typedef struct _jc_java_util_zip_CheckedOutputStream$sub_refs	_jc_java_util_zip_CheckedOutputStream$sub_refs;
typedef struct _jc_java_util_zip_CheckedOutputStream$sub_nonrefs	_jc_java_util_zip_CheckedOutputStream$sub_nonrefs;
typedef struct _jc_java_util_zip_CheckedOutputStream$refs	_jc_java_util_zip_CheckedOutputStream$refs;
typedef struct _jc_java_util_zip_CheckedOutputStream$nonrefs	_jc_java_util_zip_CheckedOutputStream$nonrefs;
typedef struct _jc_java_util_zip_CheckedOutputStream$object	_jc_java_util_zip_CheckedOutputStream$object;

typedef const struct _jc_java_util_zip_CheckedOutputStream$vmethods	_jc_java_util_zip_CheckedOutputStream$vmethods;
typedef const struct _jc_java_util_zip_CheckedOutputStream$vtable	_jc_java_util_zip_CheckedOutputStream$vtable;
typedef const struct _jc_java_util_zip_CheckedOutputStream$vtype	_jc_java_util_zip_CheckedOutputStream$vtype;

// Constructors
extern void _jc_java_util_zip_CheckedOutputStream$method$_init$404cec1cd2f6dfdd(_jc_env *, struct _jc_java_util_zip_CheckedOutputStream$object *, struct _jc_java_io_OutputStream$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_java_util_zip_CheckedOutputStream$method$getChecksum$344b1ffa660ffc14(_jc_env *, struct _jc_java_util_zip_CheckedOutputStream$object *);
extern void _jc_java_util_zip_CheckedOutputStream$method$write$6377ac6964854eb2(_jc_env *, struct _jc_java_util_zip_CheckedOutputStream$object *, jint);
extern void _jc_java_util_zip_CheckedOutputStream$method$write$306a698343ec27e8(_jc_env *, struct _jc_java_util_zip_CheckedOutputStream$object *, struct _jc_byte_array *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_java_util_zip_CheckedOutputStream$method_info$getChecksum$344b1ffa660ffc14;
extern _jc_method _jc_java_util_zip_CheckedOutputStream$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_java_util_zip_CheckedOutputStream$method_info$write$306a698343ec27e8;

// Virtual methods structure
struct _jc_java_util_zip_CheckedOutputStream$vmethods {
	struct _jc_object	*(*getChecksum$344b1ffa660ffc14)(_jc_env *, struct _jc_java_util_zip_CheckedOutputStream$object *);
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_java_util_zip_CheckedOutputStream$object *, jint);
	void	(*write$306a698343ec27e8)(_jc_env *, struct _jc_java_util_zip_CheckedOutputStream$object *, struct _jc_byte_array *, jint, jint);
};

// Vtable
struct _jc_java_util_zip_CheckedOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_java_io_FilterOutputStream$vmethods	java_io_FilterOutputStream;
	_jc_java_util_zip_CheckedOutputStream$vmethods	java_util_zip_CheckedOutputStream;
};

// Vtype
struct _jc_java_util_zip_CheckedOutputStream$vtype {
	_jc_type			type;
	_jc_java_util_zip_CheckedOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_zip_CheckedOutputStream$sub_refs {
	struct _jc_object	*sum;
};

// Reference instance fields (object)
struct _jc_java_util_zip_CheckedOutputStream$refs {
    _jc_java_util_zip_CheckedOutputStream$sub_refs	java_util_zip_CheckedOutputStream;
    _jc_java_io_FilterOutputStream$sub_refs	java_io_FilterOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_zip_CheckedOutputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_zip_CheckedOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_java_io_FilterOutputStream$sub_nonrefs	java_io_FilterOutputStream;
    _jc_java_util_zip_CheckedOutputStream$sub_nonrefs	java_util_zip_CheckedOutputStream;
};

// Object instance structure
struct _jc_java_util_zip_CheckedOutputStream$object {
	_jc_java_util_zip_CheckedOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_zip_CheckedOutputStream$vtype	*vtype;
	_jc_java_util_zip_CheckedOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_zip_CheckedOutputStream$vtype _jc_java_util_zip_CheckedOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_zip_CheckedOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_zip_CheckedOutputStream$class_object;

#endif	/* _JC_java_util_zip_CheckedOutputStream_H_ */

==> jc-1.4.6.tar.gz: java/util/zip/CheckedOutputStream.h <==
// public class java.util.zip.CheckedOutputStream

// class file dependencies
// @dep_class fddb41323d9c4cee java_io_FilterOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a389f1f7f4dc0310 java_util_zip_CheckedOutputStream

// header file dependencies
// @dep_header java_io_FilterOutputStream

#include "java/io/FilterOutputStream.h"

#ifndef _JC_java_util_zip_CheckedOutputStream_H_
#define _JC_java_util_zip_CheckedOutputStream_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_zip_Checksum$object;

// Typedefs
typedef struct _jc_java_util_zip_CheckedOutputStream$sub_refs	_jc_java_util_zip_CheckedOutputStream$sub_refs;
typedef struct _jc_java_util_zip_CheckedOutputStream$sub_nonrefs	_jc_java_util_zip_CheckedOutputStream$sub_nonrefs;
typedef struct _jc_java_util_zip_CheckedOutputStream$refs	_jc_java_util_zip_CheckedOutputStream$refs;
typedef struct _jc_java_util_zip_CheckedOutputStream$nonrefs	_jc_java_util_zip_CheckedOutputStream$nonrefs;
typedef struct _jc_java_util_zip_CheckedOutputStream$object	_jc_java_util_zip_CheckedOutputStream$object;

typedef const struct _jc_java_util_zip_CheckedOutputStream$vmethods	_jc_java_util_zip_CheckedOutputStream$vmethods;
typedef const struct _jc_java_util_zip_CheckedOutputStream$vtable	_jc_java_util_zip_CheckedOutputStream$vtable;
typedef const struct _jc_java_util_zip_CheckedOutputStream$vtype	_jc_java_util_zip_CheckedOutputStream$vtype;

// Constructors
extern void _jc_java_util_zip_CheckedOutputStream$method$_init$404cec1cd2f6dfdd(_jc_env *, struct _jc_java_util_zip_CheckedOutputStream$object *, struct _jc_java_io_OutputStream$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_java_util_zip_CheckedOutputStream$method$getChecksum$344b1ffa660ffc14(_jc_env *, struct _jc_java_util_zip_CheckedOutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_zip_CheckedOutputStream$method$write$6377ac6964854eb2(_jc_env *, struct _jc_java_util_zip_CheckedOutputStream$object *, jint) _JC_JCNI_ATTR;
extern void _jc_java_util_zip_CheckedOutputStream$method$write$306a698343ec27e8(_jc_env *, struct _jc_java_util_zip_CheckedOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_zip_CheckedOutputStream$method_info$getChecksum$344b1ffa660ffc14;
extern _jc_method _jc_java_util_zip_CheckedOutputStream$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_java_util_zip_CheckedOutputStream$method_info$write$306a698343ec27e8;

// Virtual methods structure
struct _jc_java_util_zip_CheckedOutputStream$vmethods {
	struct _jc_object	*(*getChecksum$344b1ffa660ffc14)(_jc_env *, struct _jc_java_util_zip_CheckedOutputStream$object *) _JC_JCNI_ATTR;
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_java_util_zip_CheckedOutputStream$object *, jint) _JC_JCNI_ATTR;
	void	(*write$306a698343ec27e8)(_jc_env *, struct _jc_java_util_zip_CheckedOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_zip_CheckedOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_java_io_FilterOutputStream$vmethods	java_io_FilterOutputStream;
	_jc_java_util_zip_CheckedOutputStream$vmethods	java_util_zip_CheckedOutputStream;
};

// Vtype
struct _jc_java_util_zip_CheckedOutputStream$vtype {
	_jc_type			type;
	_jc_java_util_zip_CheckedOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_zip_CheckedOutputStream$sub_refs {
	struct _jc_object	*sum;
};

// Reference instance fields (object)
struct _jc_java_util_zip_CheckedOutputStream$refs {
    _jc_java_util_zip_CheckedOutputStream$sub_refs	java_util_zip_CheckedOutputStream;
    _jc_java_io_FilterOutputStream$sub_refs	java_io_FilterOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_zip_CheckedOutputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_zip_CheckedOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_java_io_FilterOutputStream$sub_nonrefs	java_io_FilterOutputStream;
    _jc_java_util_zip_CheckedOutputStream$sub_nonrefs	java_util_zip_CheckedOutputStream;
};

// Object instance structure
struct _jc_java_util_zip_CheckedOutputStream$object {
	_jc_java_util_zip_CheckedOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_zip_CheckedOutputStream$vtype	*vtype;
	_jc_java_util_zip_CheckedOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_zip_CheckedOutputStream$vtype _jc_java_util_zip_CheckedOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_zip_CheckedOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_zip_CheckedOutputStream$class_object;

#endif	/* _JC_java_util_zip_CheckedOutputStream_H_ */
